BetweenTicks<T> class final

constructors, factories: BetweenTicks.sequence, see also TweenSequence

static methods: BetweenTicks.depend offsetArcOval, ... pathLine, ...

Inheritance

Constructors

BetweenTicks(T onLerp(double), [BiCurve? curve])
BetweenTicks.sequence(List<T> sequence, {BiCurve curve = (Curves.linear, Curves.linear), List<BiCurve>? segments, List<double>? weights, Animatable<T> construct(T begin, T end, BiCurve? curve)?})
factory

Properties

begin → T
finalinherited
curve BiCurve?
finalinherited
end → T
finalinherited
hashCode int
The hash code for this object.
no setterinherited
onLerp → T Function(double)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

animate(Animation<double> parent) Animation<T>
Returns a new Animation that is driven by the given animation but that takes on values determined by this object.
inherited
chain(Animatable<double> parent) Animatable<T>
Returns a new Animatable whose value is determined by first evaluating the given parent and then evaluating this object at the result.
inherited
evaluate(Animation<double> animation) → T
The current value of this object for the given Animation.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transform(double t) → T
Returns the value of the object at point t.
override

Operators

operator ==(covariant Between<T> other) bool
The equality operator.
inherited

Static Methods

depend<T, S>(T transform(double), S map(T)) → S Function(double)
offsetArcCircle({required Offset origin, required double radius, required Between<double> direction}) Offset Function(double)
offsetArcCircleSemi({required Offset begin, required Offset end, required bool clockwise}) Offset Function(double)
offsetArcOval({required Offset origin, required Between<double> direction, required Between<double> radius}) Offset Function(double)
offset
offsetBezierCubic({required Offset begin, required Offset c1, required Offset c2, required Offset end}) Offset Function(double)
bezier cubic
offsetBezierCubicSymmetry({required Offset begin, required Offset end, double dPerpendicular = 10, double dParallel = 1}) Offset Function(double)
offsetBezierQuadratic({required Offset begin, required Offset end, required Offset controlPoint}) Offset Function(double)
bezier quadratic
offsetBezierQuadraticSymmetry({required Offset begin, required Offset end, double dPerpendicular = 5}) Offset Function(double)
offsetCatmullRom({required List<Offset> controlPoints, double tension = 0.0, Offset? startHandle, Offset? endHandle}) Offset Function(double)
catmull rom
offsetCatmullRomSymmetry({required Offset begin, required Offset end, double dPerpendicular = 5, double dParallel = 2, double tension = 0.0, Offset? startHandle, Offset? endHandle}) Offset Function(double)
pathAdjustShapeBorder({bool outerPath = true, TextDirection? textDirection, Rect sizingRect(Size size) = _E._rectFull}) Path Function(Size) Function(ShapeBorder)
pathLine(Offset begin, Offset end, double width, {StrokeCap strokeCap = StrokeCap.round}) Path Function(double)
pathRPCOnEdge(int n, double rCircumscribe, {Offset center = Offset.zero, Between<double> edgeVectorTimes = const Between.of(0.0), Between<double> cornerRadius = const Between.of(0.0), CubicOffset cubicSwitch(CubicOffset) = _E._rpcSwitch_1342}) Path Function(double)
RPC stands for Regular Polygon bezier-Cubic