MamableTransform class final

Inheritance

Constructors

MamableTransform(Matalue<(double, double, double)> matalue, {required Matrix4 host, required Matrix4 onAnimate(Matrix4, (double, double, double)), AlignmentGeometry? alignment})
factory
MamableTransform.compose(Matalue<TransformTarget> matalue, {AlignmentGeometry? alignment})
factory
MamableTransform.rotate(Matalue<(double, double, double)> rotate, Matrix4 host, {AlignmentGeometry? alignment})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
matalue Matalue?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

hostGetPerspective(Matrix4 matrix4) double
hostSetIdentityPerspective(Matrix4 matrix4) → void
hostSetPerspective(Matrix4 matrix4, double perspective) → void
perspective = 1 / distance
hostSetRotation(Matrix4 matrix4, (double, double, double) p) Matrix4
sequenceCompose(TransformTarget previous, TransformTarget next, BiCurve curve) Mamable