MaterialTextTheme enum

see https://api.flutter.dev/flutter/material/TextTheme-class.html

default text style: DefaultTextStyle.of(context).style.fontSize in Scaffold.body, default TextStyle fontSize is 14, TextTheme.bodyMedium.

Inheritance
Available extensions

Values

displayLarge → const MaterialTextTheme
displayMedium → const MaterialTextTheme
displaySmall → const MaterialTextTheme
headlineLarge → const MaterialTextTheme
headlineMedium → const MaterialTextTheme
headlineSmall → const MaterialTextTheme
titleLarge → const MaterialTextTheme
titleMedium → const MaterialTextTheme
titleSmall → const MaterialTextTheme
bodyLarge → const MaterialTextTheme
bodyMedium → const MaterialTextTheme
bodySmall → const MaterialTextTheme
labelLarge → const MaterialTextTheme
labelMedium → const MaterialTextTheme
labelSmall → const MaterialTextTheme

Properties

buildFontSize double? Function(BuildContext context)
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MaterialTextTheme>
A constant List of the values in this enum, in order of their declaration.