- Inheritance
-
- Object
- Animatable<
T> - Matalue<
T> - Between
Constructors
- Between(T begin, T end, [BiCurve? curve])
-
factory
- Between.of(T matalue, [BiCurve? curve])
-
constfactory
Properties
Methods
-
animate(
Animation< double> parent) → Animation<T> -
Returns a new Animation that is driven by the given animation but that
takes on values determined by this object.
inherited
-
chain(
Animatable< double> parent) → Animatable<T> -
Returns a new Animatable whose value is determined by first evaluating
the given parent and then evaluating this object at the result.
inherited
-
evaluate(
Animation< double> animation) → T -
The current value of this object for the given Animation.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
transform(
double t) → T -
Returns the value of the object at point
t.inherited
Operators
-
operator ==(
covariant Between< T> other) → bool -
The equality operator.
override